@@ -35,24 +35,25 @@
 #'  `terms` (the selectors or variables selected) and `value` (the type)
 #'  is returned.
 #'
-#' @examples
+#' @template case-weights-not-supported
+#'
+#' @examplesIf rlang::is_installed("modeldata")
 #' library(dplyr)
-#' library(modeldata)
-#' data(okc)
+#' data(Sacramento, package = "modeldata")
 #'
 #' # Learn the classes on the train set
-#' train <- okc[1:1000, ]
-#' test  <- okc[1001:2000, ]
-#' recipe(train, age ~ . ) %>%
+#' train <- Sacramento[1:500, ]
+#' test <- Sacramento[501:nrow(Sacramento), ]
+#' recipe(train, sqft ~ .) %>%
 #'   check_class(everything()) %>%
 #'   prep(train, strings_as_factors = FALSE) %>%
 #'   bake(test)
 #'
 #' # Manual specification
-#' recipe(train, age ~ .) %>%
-#'   check_class(age, class_nm = "integer") %>%
-#'   check_class(diet, location, class_nm = "character") %>%
-#'   check_class(date, class_nm = "Date") %>%
+#' recipe(train, sqft ~ .) %>%
+#'   check_class(sqft, class_nm = "integer") %>%
+#'   check_class(city, zip, type, class_nm = "factor") %>%
+#'   check_class(latitude, longitude, class_nm = "numeric") %>%
 #'   prep(train, strings_as_factors = FALSE) %>%
 #'   bake(test)
 #'
@@ -72,12 +73,11 @@
 #'   check_class(time, class_nm = "POSIXt", allow_additional = TRUE) %>%
 #'   prep(x_df) %>%
 #'   bake(x_df)
-#'
 check_class <-
   function(recipe,
            ...,
            role = NA,
-           trained  = FALSE,
+           trained = FALSE,
            class_nm = NULL,
            allow_additional = FALSE,
            skip = FALSE,
@@ -116,6 +116,7 @@ check_class_new <-
     )
   }
 
+#' @export
 prep.check_class <- function(x,
                              training,
                              info = NULL,
@@ -126,7 +127,7 @@ prep.check_class <- function(x,
   # class can give back multiple values, return shape
   # is not predetermined. Thats why we use lapply instead.
   if (is.null(x$class_nm)) {
-    class_list <- lapply(training[ ,col_names], class)
+    class_list <- lapply(training[, col_names], class)
   } else {
     class_list <- rep(list(x$class_nm), length(col_names))
     names(class_list) <- col_names
@@ -163,7 +164,7 @@ bake_check_class_core <- function(x,
         " but has the class(es) ",
         paste(classes, collapse = ", "),
         "."
-    )
+      )
     )
   }
 
@@ -182,18 +183,19 @@ bake_check_class_core <- function(x,
   }
 }
 
+#' @export
 bake.check_class <- function(object,
                              new_data,
                              ...) {
-
   col_names <- names(object$class_list)
   mapply(bake_check_class_core,
-         new_data[ ,col_names],
-         object$class_list,
-         col_names,
-         MoreArgs = list(aa = object$allow_additional))
+    new_data[, col_names],
+    object$class_list,
+    col_names,
+    MoreArgs = list(aa = object$allow_additional)
+  )
 
-  as_tibble(new_data)
+  new_data
 }
 
 print.check_class <-
