@@ -117,7 +117,7 @@ step_count_new <-
 #' @export
 prep.step_count <- function(x, training, info = NULL, ...) {
   col_name <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_name], quant = FALSE)
+  check_type(training[, col_name], types = c("string", "factor", "ordered"))
 
   if (length(col_name) > 1) {
     rlang::abort("The selector should select at most a single variable")
@@ -137,6 +137,7 @@ prep.step_count <- function(x, training, info = NULL, ...) {
   )
 }
 
+#' @export
 bake.step_count <- function(object, new_data, ...) {
   check_new_data(names(object$input), object, new_data)
 
@@ -149,7 +150,7 @@ bake.step_count <- function(object, new_data, ...) {
   ## sub in options
   regex <- expr(
     gregexpr(
-      text = getElement(new_data, object$input),
+      text = new_data[[object$input]],
       pattern = object$pattern,
       ignore.case = FALSE,
       perl = FALSE,
@@ -158,12 +159,12 @@ bake.step_count <- function(object, new_data, ...) {
     )
   )
   if (length(object$options) > 0) {
-    regex <- mod_call_args(regex, args = object$options)
+    regex <- rlang::call_modify(regex, !!!object$options)
   }
 
   new_data[, object$result] <- vapply(eval(regex), counter, integer(1))
   if (object$normalize) {
-    totals <- nchar(as.character(getElement(new_data, object$input)))
+    totals <- nchar(as.character(new_data[[object$input]]))
     new_data[, object$result] <- new_data[, object$result] / totals
   }
   new_data
