@@ -167,6 +167,7 @@ step_dummy_new <-
 #' @export
 prep.step_dummy <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
+  check_type(training[, col_names], types = c("string", "factor", "ordered"))
 
   if (length(col_names) > 0) {
     col_names <- check_factor_vars(training, col_names, "step_dummy")
@@ -195,8 +196,7 @@ prep.step_dummy <- function(x, training, info = NULL, ...) {
       ## factor levels at the end of `prep.recipe` since it is
       ## not a factor anymore. We'll save them here and reset them
       ## in `bake.step_dummy` just prior to calling `model.matrix`
-      attr(levels[[i]], "values") <-
-        levels(getElement(training, col_names[i]))
+      attr(levels[[i]], "values") <- levels(training[[col_names[i]]])
       attr(levels[[i]], ".Environment") <- NULL
     }
   } else {
@@ -217,7 +217,7 @@ prep.step_dummy <- function(x, training, info = NULL, ...) {
   )
 }
 
-check_factor_vars <- function(data, col_names, step_name) {
+check_factor_vars <- function(data, col_names, step_name, call = caller_env()) {
   fac_check <- vapply(data[, col_names], is.factor, logical(1))
   if (any(!fac_check)) {
     rlang::warn(
@@ -235,7 +235,8 @@ check_factor_vars <- function(data, col_names, step_name) {
         step_name,
         "` did not select ",
         "any factor columns."
-      )
+      ),
+      call = call
     )
   }
   col_names
@@ -299,7 +300,8 @@ bake.step_dummy <- function(object, new_data, ...) {
     )
 
     new_data[, orig_var] <-
-      factor(getElement(new_data, orig_var),
+      factor(
+        new_data[[orig_var]],
         levels = attr(object$levels[[i]], "values"),
         ordered = fac_type == "ordered"
       )
@@ -329,9 +331,12 @@ bake.step_dummy <- function(object, new_data, ...) {
     ## use backticks for nonstandard factor levels here
     used_lvl <- gsub(paste0("^\\`?", col_names[i], "\\`?"), "", colnames(indicators))
     colnames(indicators) <- object$naming(col_names[i], used_lvl, fac_type == "ordered")
-    new_data <- bind_cols(new_data, as_tibble(indicators))
+    indicators <- as_tibble(indicators)
+    indicators <- check_name(indicators, new_data, object, names(indicators))
+
+    new_data <- bind_cols(new_data, indicators)
     if (any(!object$preserve, !keep_original_cols)) {
-      new_data[, col_names[i]] <- NULL
+      new_data[[col_names[i]]] <- NULL
     }
   }
   new_data
