@@ -118,7 +118,7 @@ step_impute_median_new <-
 #' @export
 prep.step_impute_median <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
@@ -180,11 +180,11 @@ tidy.step_impute_median <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(
       terms = names(x$medians),
-      model = vctrs::list_unchop(unname(x$medians), ptype = double())
+      value = vctrs::list_unchop(unname(x$medians), ptype = double())
     )
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names, model = na_dbl)
+    res <- tibble(terms = term_names, value = na_dbl)
   }
   res$id <- x$id
   res
