@@ -17,6 +17,9 @@
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #' `terms` (the columns that will be affected) is returned.
+#'
+#' @template case-weights-not-supported
+#'
 #' @examples
 #' set.seed(313)
 #' examples <- matrix(runif(40), ncol = 2)
@@ -24,7 +27,7 @@
 #'
 #' rec <- recipe(~ X1 + X2, data = examples)
 #'
-#' inverse_trans <- rec  %>%
+#' inverse_trans <- rec %>%
 #'   step_inverse(all_numeric_predictors())
 #'
 #' inverse_obj <- prep(inverse_trans, training = examples)
@@ -43,16 +46,18 @@ step_inverse <-
            columns = NULL,
            skip = FALSE,
            id = rand_id("inverse")) {
-    add_step(recipe,
-             step_inverse_new(
-               terms = enquos(...),
-               role = role,
-               offset = offset,
-               trained = trained,
-               columns = columns,
-               skip = skip,
-               id = id
-             ))
+    add_step(
+      recipe,
+      step_inverse_new(
+        terms = enquos(...),
+        role = role,
+        offset = offset,
+        trained = trained,
+        columns = columns,
+        skip = skip,
+        id = id
+      )
+    )
   }
 
 step_inverse_new <-
@@ -72,8 +77,7 @@ step_inverse_new <-
 #' @export
 prep.step_inverse <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   step_inverse_new(
     terms = x$terms,
@@ -88,10 +92,13 @@ prep.step_inverse <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_inverse <- function(object, new_data, ...) {
-  for (i in seq_along(object$columns))
-    new_data[, object$columns[i]] <-
-      1 / (new_data [[ object$columns[i] ]] + object$offset)
-  as_tibble(new_data)
+  check_new_data(names(object$columns), object, new_data)
+
+  for (i in seq_along(object$columns)) {
+    new_data[[object$columns[i]]] <-
+      1 / (new_data[[object$columns[i]]] + object$offset)
+  }
+  new_data
 }
 
 
@@ -105,7 +112,7 @@ print.step_inverse <-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_inverse <- function(x, ...) {
-  res <-simple_terms(x, ...)
+  res <- simple_terms(x, ...)
   res$id <- x$id
   res
 }
