@@ -90,10 +90,13 @@ bake.step_invlogit <- function(object, new_data, ...) {
   check_new_data(names(object$columns), object, new_data)
 
   for (i in seq_along(object$columns)) {
-    new_data[, object$columns[i]] <-
-      binomial()$linkinv(unlist(getElement(new_data, object$columns[i]),
-        use.names = FALSE
-      ))
+    new_data[[object$columns[i]]] <-
+      binomial()$linkinv(
+        unlist(
+          new_data[[object$columns[i]]],
+          use.names = FALSE
+          )
+      )
   }
   new_data
 }
