@@ -50,6 +50,12 @@
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
 #' `terms` (the selectors or variables selected) is returned.
 #'
+#' ```{r, echo = FALSE, results="asis"}
+#' step <- "step_isomap"
+#' result <- knitr::knit_child("man/rmd/tunable-args.Rmd")
+#' cat(result)
+#' ```
+#'
 #' @template case-weights-not-supported
 #'
 #' @references De Silva, V., and Tenenbaum, J. B. (2003). Global
@@ -145,8 +151,7 @@ step_isomap_new <-
 #' @export
 prep.step_isomap <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   if (x$num_terms > 0 && length(col_names) > 0L) {
     x$num_terms <- min(x$num_terms, ncol(training))
@@ -198,9 +203,10 @@ bake.step_isomap <- function(object, new_data, ...) {
         dimred_data(new_data[, isomap_vars, drop = FALSE])
       )@data
     })
-    comps <- comps[, 1:object$num_terms, drop = FALSE]
+    comps <- comps[, seq_len(object$num_terms), drop = FALSE]
+    comps <- as_tibble(comps)
     comps <- check_name(comps, new_data, object)
-    new_data <- bind_cols(new_data, as_tibble(comps))
+    new_data <- bind_cols(new_data, comps)
     keep_original_cols <- get_keep_original_cols(object)
     if (!keep_original_cols) {
       new_data <- new_data[, !(colnames(new_data) %in% isomap_vars), drop = FALSE]
