@@ -17,6 +17,14 @@
 #' @export
 #' @template kpca-info
 #'
+#' @details
+#'
+#' ```{r, echo = FALSE, results="asis"}
+#' step <- "step_kpca_poly"
+#' result <- knitr::knit_child("man/rmd/tunable-args.Rmd")
+#' cat(result)
+#' ```
+#'
 #' @template case-weights-not-supported
 #'
 #' @examplesIf rlang::is_installed(c("modeldata", "ggplot2","kernlab"))
@@ -107,8 +115,7 @@ step_kpca_poly_new <-
 #' @export
 prep.step_kpca_poly <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   if (x$num_comp > 0 && length(col_names) > 0) {
     cl <-
@@ -163,10 +170,11 @@ bake.step_kpca_poly <- function(object, new_data, ...) {
         rlang::expr(as.matrix(new_data[, object$columns]))
       )
     comps <- rlang::eval_tidy(cl)
-    comps <- comps[, 1:object$num_comp, drop = FALSE]
+    comps <- comps[, seq_len(object$num_comp), drop = FALSE]
     colnames(comps) <- names0(ncol(comps), object$prefix)
+    comps <- as_tibble(comps)
     comps <- check_name(comps, new_data, object)
-    new_data <- bind_cols(new_data, as_tibble(comps))
+    new_data <- bind_cols(new_data, comps)
     keep_original_cols <- get_keep_original_cols(object)
 
     if (!keep_original_cols) {
@@ -205,7 +213,7 @@ tunable.step_kpca_poly <- function(x, ...) {
       list(pkg = "dials", fun = "num_comp", range = c(1L, 4L)),
       list(pkg = "dials", fun = "degree"),
       list(pkg = "dials", fun = "scale_factor"),
-      list(pkg = "dials", fun = "offset")
+      list(pkg = "dials", fun = "kernel_offset")
     ),
     source = "recipe",
     component = "step_kpca_poly",
