@@ -79,8 +79,7 @@ step_logit_new <-
 #' @export
 prep.step_logit <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   step_logit_new(
     terms = x$terms,
@@ -104,7 +103,7 @@ bake.step_logit <- function(object, new_data, ...) {
   check_new_data(names(object$columns), object, new_data)
 
   for (i in seq_along(object$columns)) {
-    new_data[, object$columns[i]] <-
+    new_data[[object$columns[i]]] <-
       binomial()$linkfun(
         pre_logit(new_data[[object$columns[i]]], object$offset)
       )
