@@ -1,14 +1,5 @@
-filter_terms <- function(x, ...) {
-  UseMethod("filter_terms")
-}
-
-## get variables from formulas
-is_formula <- function(x) {
-  isTRUE(inherits(x, "formula"))
-}
-
 get_lhs_vars <- function(formula, data) {
-  if (!is_formula(formula)) {
+  if (!rlang::is_formula(formula)) {
     formula <- as.formula(formula)
   }
   ## Want to make sure that multiple outcomes can be expressed as
@@ -18,7 +9,7 @@ get_lhs_vars <- function(formula, data) {
 }
 
 get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
-  if (!is_formula(formula)) {
+  if (!rlang::is_formula(formula)) {
     formula <- as.formula(formula)
   }
   if (no_lhs) {
@@ -39,14 +30,6 @@ get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
   predictor_names
 }
 
-terms.recipe <- function(x, ...) {
-  x$term_info
-}
-
-filter_terms.formula <- function(formula, data, ...) {
-  get_rhs_vars(formula, data)
-}
-
 #' Naming Tools
 #'
 #' `names0` creates a series of `num` names with a common prefix.
@@ -98,9 +81,9 @@ filter_terms.formula <- function(formula, data, ...) {
 
 names0 <- function(num, prefix = "x") {
   if (num < 1) {
-    rlang::abort("`num` should be > 0")
+    rlang::abort("`num` should be > 0.")
   }
-  ind <- format(1:num)
+  ind <- format(seq_len(num))
   ind <- gsub(" ", "0", ind)
   paste0(prefix, ind)
 }
@@ -517,24 +500,27 @@ simple_terms <- function(x, ...) {
 #'   in the trained object.
 #' @param names A logical determining if the names should be set using
 #' the names function (TRUE) or colnames function (FALSE).
+#' @param call The execution environment of a currently running function, e.g.
+#'   `caller_env()`. The function will be mentioned in error messages as the
+#'   source of the error. See the call argument of [rlang::abort()] for more
+#'   information.
 #' @export
 #' @keywords internal
-check_name <- function(res, new_data, object, newname = NULL, names = FALSE) {
+check_name <- function(res, new_data, object, newname = NULL, names = FALSE,
+                       call = caller_env()) {
   if (is.null(newname)) {
     newname <- names0(ncol(res), object$prefix)
   }
   new_data_names <- colnames(new_data)
   intersection <- new_data_names %in% newname
   if (any(intersection)) {
-    rlang::abort(
-      paste0(
-        "Name collision occured in `",
-        class(object)[1],
-        "`. The following variable names already exists: ",
-        paste0(new_data_names[intersection], collapse = ", "),
-        "."
-      )
+    nms <- new_data_names[intersection]
+    cli::cli_abort(
+      c("Name collision occured. The following variable names already exists:",
+        i = " {nms}"),
+      call = call
     )
+
   }
   if (names) {
     names(res) <- newname
