@@ -107,10 +107,10 @@ sd_check <- function(x) {
   zero_sd <- which(x < .Machine$double.eps)
   if (length(zero_sd) > 0) {
     glue_cols <- glue::glue_collapse(
-      glue::glue("`{names(zero_sd)}`"), sep = ", ", last = " and "
+      glue("`{names(zero_sd)}`"), sep = ", ", last = " and "
     )
     rlang::warn(
-      glue::glue(
+      glue(
         "Column(s) have zero variance so scaling cannot be used: {glue_cols}. ",
         "Consider using `step_zv()` to remove those columns before normalizing"
       )
@@ -123,7 +123,7 @@ sd_check <- function(x) {
 #' @export
 prep.step_normalize <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
