@@ -30,6 +30,12 @@
 #'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
 #'  `terms` (the columns that will be affected) is returned.
 #'
+#' ```{r, echo = FALSE, results="asis"}
+#' step <- "step_ns"
+#' result <- knitr::knit_child("man/rmd/tunable-args.Rmd")
+#' cat(result)
+#' ```
+#'
 #' @template case-weights-not-supported
 #'
 #' @examplesIf rlang::is_installed("modeldata")
@@ -127,8 +133,7 @@ ns_predict <- function(object, x) {
 #' @export
 prep.step_ns <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer", "datetime"))
 
   opt <- x$options
   opt$df <- x$deg_free
@@ -161,14 +166,16 @@ bake.step_ns <- function(object, new_data, ...) {
     cols <- (strt):(strt + new_cols[i] - 1)
     orig_var <- attr(object$objects[[i]], "var")
     ns_values[, cols] <-
-      ns_predict(object$objects[[i]], getElement(new_data, i))
+      ns_predict(object$objects[[i]], new_data[[i]])
     new_names <-
       paste(orig_var, "ns", names0(new_cols[i], ""), sep = "_")
     colnames(ns_values)[cols] <- new_names
     strt <- max(cols) + 1
     new_data[, orig_var] <- NULL
   }
-  new_data <- bind_cols(new_data, as_tibble(ns_values))
+  ns_values <- as_tibble(ns_values)
+  ns_values <- check_name(ns_values, new_data, object, names(ns_values))
+  new_data <- bind_cols(new_data, ns_values)
   new_data
 }
 
