@@ -91,7 +91,7 @@ step_num2factor <-
            ordered = FALSE,
            skip = FALSE,
            id = rand_id("num2factor")) {
-    if (!is_tune(ordered) & !is_varying(ordered)) {
+    if (!is_tune(ordered)) {
       if (!is.logical(ordered) || length(ordered) != 1) {
         rlang::abort("`ordered` should be a single logical variable")
       }
@@ -138,8 +138,7 @@ get_ord_lvls_num <- function(x, foo) {
 #' @export
 prep.step_num2factor <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   res <- lapply(training[, col_names], get_ord_lvls_num, foo = x$transform)
   res <- c(res, ..levels = list(x$levels))
