@@ -29,6 +29,12 @@
 #'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #'  `terms` (the columns that will be affected) and `degree` is returned.
 #'
+#' ```{r, echo = FALSE, results="asis"}
+#' step <- "step_poly"
+#' result <- knitr::knit_child("man/rmd/tunable-args.Rmd")
+#' cat(result)
+#' ```
+#'
 #' @template case-weights-not-supported
 #'
 #' @examplesIf rlang::is_installed("modeldata")
@@ -147,7 +153,7 @@ prep.step_poly <- function(x, training, info = NULL, ...) {
 bake.step_poly <- function(object, new_data, ...) {
   col_names <- names(object$objects)
   check_new_data(col_names, object, new_data)
-  new_names <- purrr::map(object$objects, ~ paste(attr(.x, "var"), "poly", 1:ncol(.x), sep = "_"))
+  new_names <- purrr::map(object$objects, ~ paste(attr(.x, "var"), "poly", seq_len(ncol(.x)), sep = "_"))
 
   # Start with n-row, 0-col tibble for the empty selection case
   new_tbl <- tibble::new_tibble(x = list(), nrow = nrow(new_data))
@@ -165,7 +171,8 @@ bake.step_poly <- function(object, new_data, ...) {
     new_tbl[i_new_names] <- new_cols
   }
 
-  new_data <- dplyr::bind_cols(new_data, new_tbl)
+  new_tbl <- check_name(new_tbl, new_data, object, names(new_tbl))
+  new_data <- bind_cols(new_data, new_tbl)
   new_data <- dplyr::select(new_data, -dplyr::all_of(col_names))
   new_data
 }
