@@ -133,7 +133,7 @@ bake.step_sample <- function(object, new_data, ...) {
 
   if (isTRUE(object$case_weights)) {
     wts_col <- purrr::map_lgl(new_data, hardhat::is_case_weights)
-    wts <- getElement(new_data, names(which(wts_col)))
+    wts <- new_data[[names(which(wts_col))]]
     wts <- as.double(wts)
   } else {
     wts <- NULL
