@@ -172,29 +172,30 @@ recipes_eval_select <- function(quos, data, info, ..., allow_rename = FALSE,
                                 check_case_weights = TRUE, call = caller_env()) {
   ellipsis::check_dots_empty()
 
+  if (rlang::is_missing(quos)) {
+    rlang::abort('argument "quos" is missing, with no default.')
+  }
+
   # Maintain ordering between `data` column names and `info$variable` so
   # `eval_select()` and recipes selectors return compatible positions
-  data_info <- tibble(variable = names(data))
-  data_info <- dplyr::left_join(data_info, info, by = "variable", multiple = "all")
+  matches <- vctrs::vec_locate_matches(names(data), info$variable, no_match = "error")
+  data_info <- vec_slice(info, matches$haystack)
 
-  nested_info <- tidyr::nest(data_info, data = -variable)
+  data_nest <- data_info[names(data_info) != "variable"]
+  data_nest <- tibble::new_tibble(data_nest, nrow = vctrs::vec_size(data_nest))
+
+  nested_info <- vctrs::vec_split(data_nest, by = data_info$variable)
+  nested_info <- list(variable = nested_info$key, data = nested_info$val)
+  nested_info <- tibble::new_tibble(nested_info, nrow = length(nested_info$variable))
 
   local_current_info(nested_info)
 
   expr <- expr(c(!!!quos))
 
-  # FIXME: Ideally this is `FALSE` for strict selection,
-  # but empty selections incorrectly throw an
-  # error when this is false due to the following bug:
-  # https://github.com/r-lib/tidyselect/issues/221
-  # Once it's fixed, remove this and pass allow_rename to
-  # tidyselect::eval_select().
-  allow_rename_compat <- TRUE
-
   sel <- tidyselect::eval_select(
     expr = expr,
     data = data,
-    allow_rename = allow_rename_compat,
+    allow_rename = allow_rename,
     error_call = call
   )
 
@@ -204,13 +205,6 @@ recipes_eval_select <- function(quos, data, info, ..., allow_rename = FALSE,
   out <- names(data)[sel]
   names <- names(sel)
 
-  # FIXME: Remove this check when the following issue is fixed,
-  # at that point, just pass `allow_rename` to `eval_select()` directly.
-  # https://github.com/r-lib/tidyselect/issues/221
-  if (!allow_rename & !identical(out, names)) {
-    abort("Can't rename variables in this context.", call = call)
-  }
-
   if (check_case_weights &&
       any(out %in% info$variable[info$role == "case_weights"])) {
     abort("Cannot select case weights variable.", call = call)
@@ -459,8 +453,6 @@ all_unordered_predictors <- function() {
 
 ## functions to get current variable info for selectors modeled after
 ## dplyr versions
-
-#' @import rlang
 cur_info_env <- env(empty_env())
 
 local_current_info <- function(nested_info, frame = parent.frame()) {
