@@ -31,6 +31,12 @@
 #'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
 #'  `terms` (the columns that will be affected) is returned.
 #'
+#' ```{r, echo = FALSE, results="asis"}
+#' step <- "step_spline_convex"
+#' result <- knitr::knit_child("man/rmd/tunable-args.Rmd")
+#' cat(result)
+#' ```
+#'
 #' @examplesIf rlang::is_installed(c("modeldata", "ggplot2"))
 #' library(tidyr)
 #' library(dplyr)
@@ -109,7 +115,7 @@ step_spline_convex_new <-
   }
 
 # ------------------------------------------------------------------------------
-
+#' @export
 prep.step_spline_convex <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
@@ -149,10 +155,12 @@ prep.step_spline_convex <- function(x, training, info = NULL, ...) {
   )
 }
 
+#' @export
 bake.step_spline_convex <- function(object, new_data, ...) {
   orig_names <- names(object$results)
   if (length(orig_names) > 0) {
     new_cols <- purrr::map2_dfc(object$results, new_data[, orig_names], spline2_apply)
+    new_cols <- check_name(new_cols, new_data, object, names(new_cols))
     new_data <- bind_cols(new_data, new_cols)
     keep_original_cols <- get_keep_original_cols(object)
     if (!keep_original_cols) {
@@ -205,7 +213,7 @@ tunable.step_spline_convex <- function(x, ...) {
     name = c("deg_free", "degree"),
     call_info = list(
       list(pkg = "dials", fun = "spline_degree", range = c(2L, 15L)),
-      list(pkg = "dials", fun = "degree", range = c(0L, 3L))
+      list(pkg = "dials", fun = "degree_int", range = c(0L, 3L))
     ),
     source = "recipe",
     component = "step_spline_convex",
