@@ -14,6 +14,9 @@
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
 #' `terms` (the columns that will be affected) is returned.
+#'
+#' @template case-weights-not-supported
+#'
 #' @export
 #' @examples
 #' set.seed(313)
@@ -22,7 +25,7 @@
 #'
 #' rec <- recipe(~ V1 + V2, data = examples)
 #'
-#' sqrt_trans <- rec  %>%
+#' sqrt_trans <- rec %>%
 #'   step_sqrt(all_numeric_predictors())
 #'
 #' sqrt_obj <- prep(sqrt_trans, training = examples)
@@ -66,7 +69,7 @@ step_sqrt_new <-
 #' @export
 prep.step_sqrt <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names])
+  check_type(training[, col_names], types = c("double", "integer"))
 
   step_sqrt_new(
     terms = x$terms,
@@ -80,11 +83,13 @@ prep.step_sqrt <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_sqrt <- function(object, new_data, ...) {
+  check_new_data(names(object$columns), object, new_data)
+
   col_names <- object$columns
-  for (i in seq_along(col_names))
-    new_data[, col_names[i]] <-
-      sqrt(getElement(new_data, col_names[i]))
-  as_tibble(new_data)
+  for (i in seq_along(col_names)) {
+    new_data[[col_names[i]]] <- sqrt(new_data[[col_names[i]]])
+  }
+  new_data
 }
 
 print.step_sqrt <- function(x, width = max(20, options()$width - 29), ...) {
@@ -96,7 +101,7 @@ print.step_sqrt <- function(x, width = max(20, options()$width - 29), ...) {
 #' @rdname tidy.recipe
 #' @export
 tidy.step_sqrt <- function(x, ...) {
-  res <-simple_terms(x, ...)
+  res <- simple_terms(x, ...)
   res$id <- x$id
   res
 }
