@@ -118,15 +118,7 @@ step_time_new <-
 #' @export
 prep.step_time <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-
-  if (!all(purrr::map_lgl(training[, col_names], inherits, "POSIXt"))) {
-    rlang::abort(
-      paste0(
-        "All variables for `step_time` should be either `POSIXlt` or",
-        "`POSIXct` classes."
-      )
-    )
-  }
+  check_type(training[, col_names], types = "datetime")
 
   step_time_new(
     terms = x$terms,
@@ -150,7 +142,8 @@ bake.step_time <- function(object, new_data, ...) {
       feats = object$features
     )
 
-    names(time_values) <- glue::glue("{column}_{names(time_values)}")
+    names(time_values) <- glue("{column}_{names(time_values)}")
+    time_values <- check_name(time_values, new_data, object, names(time_values))
     new_data <- bind_cols(new_data, time_values)
   }
 
